@@ -6,7 +6,7 @@ from utils.current_timestamp import get_current_timestamp_ms
 
 @unique
 class SourceTypes(str, Enum):
-    topic = 'topic'
+    thread = 'thread'
     comment = 'comment'
 
 
